==> qore-0.9.4.5.tar.bz2: qore-0.9.4.5/docs/modules/SalesforceRestDataProvider/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore SalesforceRestDataProvider Module Reference", "index.html", [
    [ "SalesforceRestDataProvider Module", "index.html", [
      [ "Introduction to the SalesforceRestDataProvider Module", "index.html#salesforcerestdataproviderintro", null ],
      [ "Salesforce Queries", "index.html#salesforcerestdataprovider_queries", null ],
      [ "Release Notes", "index.html#salesforcerestdataprovider_relnotes", [
        [ "SalesforceRestDataProvider v1.0.1", "index.html#salesforcerestdataprovider_v1_0", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__date__and__time__functions.html#ga9200d06a35e6a2c19aa2a6c952a049c0",
"group__file__locking__constants.html#gaf9d120de60979f848d7d145db05c4403",
"group__math__constants.html#ga2326203043f44a1fe37ffebe35ab8513",
"group__option__constants.html#ga19571712256d5f9817d58c38584510e6",
"group__string__functions.html#ga7804f63df9b181e0bacb465eb912feb9",
"group__warning__constants.html#ga5d8afd6e29d7ceba003d8869c2bbe5e1"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-0.9.4.6.tar.bz2: qore-0.9.4.6/docs/modules/SalesforceRestDataProvider/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore SalesforceRestDataProvider Module Reference", "index.html", [
    [ "SalesforceRestDataProvider Module", "index.html", [
      [ "Introduction to the SalesforceRestDataProvider Module", "index.html#salesforcerestdataproviderintro", null ],
      [ "Salesforce Queries", "index.html#salesforcerestdataprovider_queries", null ],
      [ "Release Notes", "index.html#salesforcerestdataprovider_relnotes", [
        [ "SalesforceRestDataProvider v1.0.1", "index.html#salesforcerestdataprovider_v1_0", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__date__and__time__functions.html#ga83e582adb5ad1401911345ba306dabd2",
"group__exception__type__constants.html#ga1b83beab5fce1ac7290ea7d93e49eeac",
"group__list__functions.html#gadd91030761ee2fa0b1783f76b2ea467c",
"group__old__dbi__functions.html#gaba3a2421c3d2b492c9494f346c13da1c",
"group__string__functions.html#ga69274a2dc60bef5acb7a8adad8b96b8b",
"group__warning__constants.html#ga123728981ed0a5970536f94bcbcd88b1"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
